==> haskell-echo-0.1.3-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-echo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 echo
version:              0.1.3
visibility:           public
id:                   echo-0.1.3-99qFNEI1tQV82aLDr0wZDb
key:                  echo-0.1.3-99qFNEI1tQV82aLDr0wZDb
license:              BSD-3-Clause
copyright:            (C) 2016-2017 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
stability:            Provisional
homepage:             https://github.com/RyanGlScott/echo
synopsis:
    A cross-platform, cross-console way to handle echoing terminal input

description:
    The @base@ library exposes the @hGetEcho@ and @hSetEcho@ functions
    for querying and setting echo status, but unfortunately, neither
    function works with MinTTY consoles on Windows. This is a serious
    issue, since @hGetEcho@ and @hSetEcho@ are often used to disable
    input echoing when a program prompts for a password, so many
    programs will reveal your password as you type it on MinTTY!

    This library provides an alternative interface which works
    with both MinTTY and other consoles. An example is included
    which demonstrates how one might prompt for a password using
    this library. To build it, make sure to configure with the
    @-fexample@ flag.

category:             System
abi:                  093276984a0aa1789e1ed701f4b10024
exposed:              True
exposed-modules:      System.IO.Echo System.IO.Echo.Internal
import-dirs:          /usr/lib/ghc-8.8.1/site-local/echo-0.1.3
library-dirs:         /usr/lib/ghc-8.8.1/site-local/echo-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/echo-0.1.3
hs-libraries:         HSecho-0.1.3-99qFNEI1tQV82aLDr0wZDb
depends:              base-4.13.0.0 process-1.6.5.1
haddock-interfaces:   /usr/share/doc/haskell-echo/html/echo.haddock
haddock-html:         /usr/share/doc/haskell-echo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-echo-0.1.3-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-echo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 echo
version:              0.1.3
visibility:           public
id:                   echo-0.1.3-AfpGXTKQEtm1k4cy60i2OQ
key:                  echo-0.1.3-AfpGXTKQEtm1k4cy60i2OQ
license:              BSD-3-Clause
copyright:            (C) 2016-2017 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
stability:            Provisional
homepage:             https://github.com/RyanGlScott/echo
synopsis:
    A cross-platform, cross-console way to handle echoing terminal input

description:
    The @base@ library exposes the @hGetEcho@ and @hSetEcho@ functions
    for querying and setting echo status, but unfortunately, neither
    function works with MinTTY consoles on Windows. This is a serious
    issue, since @hGetEcho@ and @hSetEcho@ are often used to disable
    input echoing when a program prompts for a password, so many
    programs will reveal your password as you type it on MinTTY!

    This library provides an alternative interface which works
    with both MinTTY and other consoles. An example is included
    which demonstrates how one might prompt for a password using
    this library. To build it, make sure to configure with the
    @-fexample@ flag.

category:             System
abi:                  b94aa7197f1aa3c82e04f73b01a9b751
exposed:              True
exposed-modules:      System.IO.Echo System.IO.Echo.Internal
import-dirs:          /usr/lib/ghc-8.8.2/site-local/echo-0.1.3
library-dirs:         /usr/lib/ghc-8.8.2/site-local/echo-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/echo-0.1.3
hs-libraries:         HSecho-0.1.3-AfpGXTKQEtm1k4cy60i2OQ
depends:              base-4.13.0.0 process-1.6.7.0
haddock-interfaces:   /usr/share/doc/haskell-echo/html/echo.haddock
haddock-html:         /usr/share/doc/haskell-echo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
